Plain-throw assertion helpers for auth-engine Result/Option/phase tests.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
err<
T> (Result< T> result, {String? reason}) → Problem -
Asserts
resultis aErrand returns its problem. -
errType<
T> (Result< T> result, String type) → Problem -
Asserts
resultis aErrwhose problemtypeequalstype. -
none<
T> (Option< T> option, {String? reason}) → void -
Asserts
optionisNone. -
ok<
T> (Result< T> result, {String? reason}) → T -
Asserts
resultis aOkand returns its value. -
phase(
OnboardingPhase actual, OnboardingPhase expected) → void -
Asserts the terminal onboarding phase equals
expected. -
some<
T> (Option< T> option, {String? reason}) → T -
Asserts
optionisSomeand returns its value. -
status(
Problem problem, int expected) → void -
Asserts
problemcarries the expectedstatus.