FakeLandscapeSelectorSource class final

Fake Doc B source returning a fixed doc (or throwing).

Implemented types

Properties

doc LandscapeSelectorDoc?
getter/setter pair
error Object?
getter/setter pair
fetchCount int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetch() Future<LandscapeSelectorDoc>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited