FakeRegionPinger class final
Fake region pinger backed by a latency map keyed by landscape name; a null
entry (or a missing name) is unhealthy.
- Implemented types
Constructors
-
FakeRegionPinger(Map<
String, Duration?> latencies)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ping(
LandscapeEntry entry) → Future< Duration?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited