MemoryHomeClaimStore class final

In-memory HomeClaimStore.

Implemented types

Constructors

MemoryHomeClaimStore([String? value])

Properties

hashCode int
The hash code for this object.
no setterinherited
reads int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
getter/setter pair
writes int
getter/setter pair

Methods

clear() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() Future<String?>
override
toString() String
A string representation of this object.
inherited
write(String landscape) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited