FakeAppHandoffApi class final
Scriptable AppHandoffApi fake.
- Implemented types
Constructors
-
FakeAppHandoffApi({Result<
RedeemResult> ? result})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastNonce ↔ String?
-
getter/setter pair
- redeemCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redeem(
{required String nonce, required DeviceInfo device}) → Future< Result< RedeemResult> > -
Redeems
noncewith telemetry-onlydevice. Returns the minted one-time token on success, or the generic-expiryProblemotherwise.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited