FakeUserDirectory class final

Scriptable UserDirectory fake.

Implemented types

Constructors

FakeUserDirectory({int getStatus = 200, int postStatus = 201, bool throwOnGet = false})

Properties

getCount int
getter/setter pair
getStatus int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
postCount int
getter/setter pair
postStatus int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
throwOnGet bool
getter/setter pair

Methods

getUserMe({required String backendId, required String accessToken}) Future<int>
GET {backend}/User/Me with the bearer accessToken. Returns the status (200 = row exists, 404 = create path).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postUser({required String backendId, required String accessToken, required String idToken}) Future<int>
POST {backend}/User with the bearer accessToken and body { "idToken": ..., "accessToken": ... }. Any 2xx or 409 is create-or-ok.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited